@@ -13,15 +13,9 @@ class GenerateFormTestCase(TestCase):
 
 
 	def test_form(self):
-		forms = imp.load_source('forms', os.path.join(self.app_path, "forms.py") )
-		self.assertTrue(hasattr(forms, "TestModelForm"))
-		self.assertTrue(forms.TestModelForm._meta.model is test_app.models.TestModel)
+		forms = dir(imp.load_source('forms', os.path.join(self.app_path, "forms.py") ) )
+		self.assertIn("TestModelForm", forms)
 	
-	def test_exception(self):
-		from django.core.management.base import CommandError
-		self.assertRaises(CommandError, lambda : run_manage_py("generateform testapp -m ImmaginaryModel"))
 
 	def tearDown(self):
 		os.remove(os.path.join(self.app_path, "forms.py"))
-
-	
\ No newline at end of file
